import setuptools
from pathlib import Path

setuptools.setup(
    name="lyypdf",  # unique，不能与pypi存储库中的包重名
    version=1.3,
    long_description=Path("README.md").read_text(),
    # 告诉 what packages are going to be 分发distributed
    # 因为在这个项目中，目前有一个package：lyypdf
    # lyypdf 包中两个modules：pdf2image, pdf2text

    # 查找项目并自动发现我们定义了的packages，但是需要告诉他派出两个目录test和data【setuptools.find_packages([排除字符串])】
    packages=setuptools.find_packages(exclude=["tests", "data"])
)



""" This module provides functions to conver a PDF too text.
"""


class Converter:
    """
    A simple converter for converting PDFs to text.
    """

    def convert(self, path):
        """ 
        Convert the given PDF to text

        Parameters: 
        path (str): The path to a PDF file.

        Returns:
        str: The content of the PDF file as text.
        """
        print("pdf2text")
